@@ -35,7 +35,6 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
@@ -61,11 +60,6 @@ describe 'nova::compute' do
         is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
       end
-
-      it 'configures nova pci_passthrough_whitelist' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
     end
 
     context 'with overridden parameters' do
@@ -147,85 +141,14 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with reserved_huge_pages string' do
-      let :params do
-        {
-            :reserved_huge_pages => "foo"
-        }
-      end
-      it 'configures nova reserved_huge_pages entries' do
-        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
-          'value' => 'foo'
-        )
-      end
-    end
-
-    context 'with reserved_huge_pages array' do
-      let :params do
-        {
-            :reserved_huge_pages => ["foo", "bar"]
-        }
-      end
-      it 'configures nova reserved_huge_pages entries' do
-        is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with(
-          'value' => ['foo','bar']
-        )
-      end
-    end
-
-    context 'with pci params array' do
-      let :params do
-        {
-          :pci_passthrough => [
-            {
-              "vendor_id"  => "8086",
-              "product_id" => "0126"
-            },
-            {
-              "vendor_id"        => "9096",
-              "product_id"       => "1520",
-              "physical_network" => "physnet1"
-            }
-          ],
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'with pci params JSON encoded string (deprecated)' do
-      let :params do
-        {
-          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
     context 'when vcpu_pin_set and pci params are empty' do
       let :params do
-        { :vcpu_pin_set    => "",
-          :pci_passthrough => ""}
+        { :vcpu_pin_set    => ""}
       end
 
       it 'clears vcpu_pin_set configuration' do
         is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>')
       end
-      it 'clears pci_passthrough configuration' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
     end
 
     context 'with neutron_enabled set to false' do
